@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -6,14 +6,14 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-mod blob_apis;
 mod commands;
 mod data;
+mod file_apis;
 mod queries;
 mod register_apis;
 
 use crate::client::{connections::Session, errors::Error, ClientConfig};
-use crate::messaging::data::{CmdError, DataQuery, RegisterRead, ServiceMsg};
+use crate::messaging::data::{CmdError, DataQuery, RegisterQuery, ServiceMsg};
 use crate::messaging::{ServiceAuth, WireMsg};
 use crate::peer::Peer;
 use crate::prefix_map::NetworkPrefixMap;
@@ -75,6 +75,7 @@ impl Client {
         Client::create_with(config, bootstrap_nodes, optional_keypair, true).await
     }
 
+    #[instrument]
     pub(crate) async fn create_with(
         config: ClientConfig,
         bootstrap_nodes: BTreeSet<SocketAddr>,
@@ -168,7 +169,7 @@ impl Client {
         // Generate a random query to send a dummy message
         let random_dst_addr = XorName::random();
         let serialised_cmd = {
-            let msg = ServiceMsg::Query(DataQuery::Register(RegisterRead::Get(
+            let msg = ServiceMsg::Query(DataQuery::Register(RegisterQuery::Get(
                 RegisterAddress::Public {
                     name: random_dst_addr,
                     tag: 1,
