@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -16,15 +16,18 @@ mod register;
 
 pub use self::{
     cmd::DataCmd,
-    data_exchange::{ChunkDataExchange, DataExchange, RegisterDataExchange, StorageLevel},
+    data_exchange::{DataExchange, RegisterStoreExport, ReplicatedRegisterLog, StorageLevel},
     errors::{Error, Result},
     query::DataQuery,
-    register::{RegisterCmd, RegisterRead, RegisterWrite},
+    register::{
+        CreateRegister, DeleteRegister, EditRegister, ExtendRegister, RegisterCmd, RegisterQuery,
+        SignedRegisterCreate, SignedRegisterDelete, SignedRegisterEdit, SignedRegisterExtend,
+    },
 };
 
 use crate::types::{
-    register::{Entry, EntryHash, Permissions, Policy, Register},
-    Chunk, ChunkAddress, DataAddress, PublicKey,
+    register::{Entry, EntryHash, Permissions, Policy, Register, User},
+    Chunk, ChunkAddress, DataAddress,
 };
 use crate::{
     messaging::{data::Error as ErrorMessage, MessageId},
@@ -131,16 +134,23 @@ pub enum QueryResponse {
     //
     // ===== Register Data =====
     //
-    /// Response to [`RegisterRead::Get`].
+    /// Response to [`RegisterQuery::Get`].
     GetRegister((Result<Register>, OperationId)),
-    /// Response to [`RegisterRead::GetOwner`].
-    GetRegisterOwner((Result<PublicKey>, OperationId)),
-    /// Response to [`RegisterRead::Read`].
+    /// Response to [`RegisterQuery::GetEntry`].
+    GetRegisterEntry((Result<Entry>, OperationId)),
+    /// Response to [`RegisterQuery::GetOwner`].
+    GetRegisterOwner((Result<User>, OperationId)),
+    /// Response to [`RegisterQuery::Read`].
     ReadRegister((Result<BTreeSet<(EntryHash, Entry)>>, OperationId)),
-    /// Response to [`RegisterRead::GetPolicy`].
+    /// Response to [`RegisterQuery::GetPolicy`].
     GetRegisterPolicy((Result<Policy>, OperationId)),
-    /// Response to [`RegisterRead::GetUserPermissions`].
+    /// Response to [`RegisterQuery::GetUserPermissions`].
     GetRegisterUserPermissions((Result<Permissions>, OperationId)),
+    //
+    // ===== Other =====
+    //
+    /// Failed to create id generation
+    FailedToCreateOperationId,
 }
 
 impl QueryResponse {
@@ -150,10 +160,12 @@ impl QueryResponse {
         match self {
             GetChunk(result) => result.is_ok(),
             GetRegister((result, _op_id)) => result.is_ok(),
+            GetRegisterEntry((result, _op_id)) => result.is_ok(),
             GetRegisterOwner((result, _op_id)) => result.is_ok(),
             ReadRegister((result, _op_id)) => result.is_ok(),
             GetRegisterPolicy((result, _op_id)) => result.is_ok(),
             GetRegisterUserPermissions((result, _op_id)) => result.is_ok(),
+            FailedToCreateOperationId => false,
         }
     }
 
@@ -170,6 +182,10 @@ impl QueryResponse {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
+            GetRegisterEntry((result, _op_id)) => match result {
+                Ok(_) => false,
+                Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
+            },
             GetRegisterOwner((result, _op_id)) => match result {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
@@ -186,6 +202,7 @@ impl QueryResponse {
                 Ok(_) => false,
                 Err(error) => matches!(*error, ErrorMessage::DataNotFound(_)),
             },
+            FailedToCreateOperationId => false,
         }
     }
 
@@ -214,12 +231,13 @@ impl QueryResponse {
                     Err(Error::InvalidQueryResponseErrorForOperationId)
                 }
             },
-
             GetRegister((_, operation_id))
+            | GetRegisterEntry((_, operation_id))
             | GetRegisterOwner((_, operation_id))
             | ReadRegister((_, operation_id))
             | GetRegisterPolicy((_, operation_id))
             | GetRegisterUserPermissions((_, operation_id)) => Ok(operation_id.clone()),
+            FailedToCreateOperationId => Err(Error::NoOperationId),
         }
     }
 }
@@ -266,7 +284,7 @@ impl TryFrom<QueryResponse> for Chunk {
 }
 
 try_from!(Register, GetRegister);
-try_from!(PublicKey, GetRegisterOwner);
+try_from!(User, GetRegisterOwner);
 try_from!(BTreeSet<(EntryHash, Entry)>, ReadRegister);
 try_from!(Policy, GetRegisterPolicy);
 try_from!(Permissions, GetRegisterUserPermissions);
@@ -274,7 +292,7 @@ try_from!(Permissions, GetRegisterUserPermissions);
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::types::{utils::random_bytes, Chunk, Keypair};
+    use crate::types::{utils::random_bytes, Chunk, Keypair, PublicKey};
     use bytes::Bytes;
     use eyre::{eyre, Result};
     use std::convert::{TryFrom, TryInto};
@@ -300,7 +318,7 @@ mod tests {
     fn debug_format_functional() -> Result<()> {
         if let Some(key) = gen_keys().first() {
             let errored_response = QueryResponse::GetRegister((
-                Err(Error::AccessDenied(*key)),
+                Err(Error::AccessDenied(User::Key(*key))),
                 "some_op_id".to_string(),
             ));
             assert!(format!("{:?}", errored_response).contains("GetRegister((Err(AccessDenied("));
@@ -314,7 +332,7 @@ mod tests {
     fn try_from() -> Result<()> {
         use QueryResponse::*;
         let key = match gen_keys().first() {
-            Some(key) => *key,
+            Some(key) => User::Key(*key),
             None => return Err(eyre!("Could not generate public key")),
         };
 
