@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -305,15 +305,15 @@ impl Dispatcher {
     pub(super) async fn enqueue_and_handle_next_command_and_any_offshoots(
         self: Arc<Self>,
         command: Command,
-        cmd_id: Option<String>,
+        cmd_id: Option<CmdId>,
     ) -> Result<()> {
         let _ = tokio::spawn(async {
-            let cmd_id = cmd_id.unwrap_or_else(|| rand::random::<u32>().to_string());
-
+            let cmd_id: CmdId = cmd_id.unwrap_or_else(|| rand::random::<u32>().to_string());
             self.acquire_permit_or_wait(command.priority()?, cmd_id.clone())
                 .await?;
 
-            self.handle_command_and_any_offshoots(command, cmd_id).await
+            self.handle_command_and_any_offshoots(command, Some(cmd_id))
+                .await
         });
         Ok(())
     }
@@ -325,15 +325,16 @@ impl Dispatcher {
     pub(super) async fn handle_command_and_any_offshoots(
         self: Arc<Self>,
         command: Command,
-        cmd_id: String,
+        cmd_id: Option<CmdId>,
     ) -> Result<()> {
+        let cmd_id = cmd_id.unwrap_or_else(|| rand::random::<u32>().to_string());
         let cmd_id_clone = cmd_id.clone();
         let command_display = command.to_string();
-        let _ = tokio::spawn(async move {
+        let _task = tokio::spawn(async move {
             match self.process_command(command, &cmd_id).await {
                 Ok(commands) => {
                     for (sub_cmd_count, command) in commands.into_iter().enumerate() {
-                        let sub_cmd_id = format!("{}.{}", cmd_id, sub_cmd_count);
+                        let sub_cmd_id = format!("{}.{}", &cmd_id, sub_cmd_count);
                         // Error here is only related to queueing, and so a dropped command will be logged
                         let _result = self.clone().spawn_handle_commands(command, sub_cmd_id);
                     }
@@ -348,21 +349,17 @@ impl Dispatcher {
             "{:?} {} cmd_id={}",
             LogMarker::CommandHandleSpawned,
             command_display,
-            cmd_id_clone
+            &cmd_id_clone
         );
-
         Ok(())
     }
 
     // Note: this indirecton is needed. Trying to call `spawn(self.handle_commands(...))` directly
     // inside `handle_commands` causes compile error about type check cycle.
     fn spawn_handle_commands(self: Arc<Self>, command: Command, cmd_id: String) -> Result<()> {
-        // self.enqueue_command(command)?;
-        // if let Some(command) = self.get_next_command_to_handle() {
-        let _ = tokio::spawn(
+        let _task = tokio::spawn(
             self.enqueue_and_handle_next_command_and_any_offshoots(command, Some(cmd_id)),
         );
-        // }
         Ok(())
     }
 
@@ -569,9 +566,6 @@ impl Dispatcher {
                 .await
                 .into_iter()
                 .collect()),
-            Command::SetJoinsAllowed(joins_allowed) => {
-                self.core.set_joins_allowed(joins_allowed).await
-            }
             Command::SendAcceptedOnlineShare {
                 peer,
                 previous_name,
@@ -588,7 +582,7 @@ impl Dispatcher {
             ]),
             Command::TestConnectivity(name) => {
                 let mut commands = vec![];
-                if let Some(member_info) = self.core.network_knowledge().members().get(&name) {
+                if let Some(member_info) = self.core.network_knowledge().get_section_member(&name) {
                     if self
                         .core
                         .comm
@@ -619,7 +613,7 @@ impl Dispatcher {
                 if let Err(err) = self
                     .core
                     .comm
-                    .send_on_existing_connection(recipients, wire_msg.clone())
+                    .send_on_existing_connection_to_client(recipients, wire_msg.clone())
                     .await
                 {
                     error!("Failed sending message {:?} to recipients {:?} on existing connection with error {:?}",
