@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -217,15 +217,6 @@ impl Routing {
         Ok((routing, event_stream))
     }
 
-    /// Sets the JoinsAllowed flag.
-    pub async fn set_joins_allowed(&self, joins_allowed: bool) -> Result<()> {
-        let command = Command::SetJoinsAllowed(joins_allowed);
-        self.dispatcher
-            .clone()
-            .enqueue_and_handle_next_command_and_any_offshoots(command, None)
-            .await
-    }
-
     /// Signals the Elders of our section to test connectivity to a node.
     pub async fn start_connectivity_test(&self, name: XorName) -> Result<()> {
         let command = Command::StartConnectivityTest(name);
