@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -180,7 +180,7 @@ impl<'a> Join<'a> {
                     section_chain,
                     node_state,
                 } => {
-                    trace!("{}", LogMarker::ReceivedJoinApproved);
+                    trace!("{}", LogMarker::ReceivedJoinApproval);
                     if node_state.name != self.node.name() {
                         trace!("Ignore NodeApproval not for us: {:?}", node_state);
                         continue;
