@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -117,12 +117,16 @@ impl Comm {
     }
 
     /// Sends a message on an existing connection. If no such connection exists, returns an error.
-    pub(crate) async fn send_on_existing_connection(
+    /// Drops the connection after the message has been sent.
+    pub(crate) async fn send_on_existing_connection_to_client(
         &self,
         recipients: &[Peer],
         mut wire_msg: WireMsg,
     ) -> Result<(), Error> {
-        trace!("Sending msg on existing connection to {:?}", recipients);
+        trace!(
+            "Sending msg on existing connection to client {:?}",
+            recipients
+        );
         for recipient in recipients {
             let name = recipient.name();
             let addr = recipient.addr();
