@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -159,7 +159,7 @@ async fn candidates(
 
 // Returns a `Peer` for a known node.
 fn get_peer(name: &XorName, network_knowledge: &NetworkKnowledge) -> Option<Peer> {
-    match network_knowledge.members().get(name) {
+    match network_knowledge.get_section_member(name) {
         Some(info) => Some(info.peer().clone()),
         None => network_knowledge
             .section_by_name(name)
