@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -7,7 +7,6 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    data::DataExchange,
     system::{
         DkgSessionId, JoinResponse, NodeCmd, RelocateDetails, RelocatePromise, SectionAuth,
         SystemMsg,
@@ -133,13 +132,8 @@ impl Core {
     // ------------------------------------------------------------------------------------------------------------
     // ------------------------------------------------------------------------------------------------------------
 
-    /// Generate AntiEntropyUpdate message to update a peer with proof_chain,
-    /// and members_info if required.
-    pub(crate) async fn generate_ae_update(
-        &self,
-        dst_section_key: BlsPublicKey,
-        add_peer_info_to_update: bool,
-    ) -> Result<SystemMsg> {
+    /// Generate AntiEntropyUpdate message to update a peer with proof_chain and members list.
+    async fn generate_ae_update_msg(&self, dst_section_key: BlsPublicKey) -> Result<SystemMsg> {
         let section_signed_auth = self
             .network_knowledge
             .section_signed_authority_provider()
@@ -160,17 +154,12 @@ impl Core {
             }
         };
 
-        let members = if add_peer_info_to_update {
-            Some(
-                self.network_knowledge
-                    .members()
-                    .iter()
-                    .map(|state| state.clone().into_authed_msg())
-                    .collect(),
-            )
-        } else {
-            None
-        };
+        let members = self
+            .network_knowledge
+            .section_signed_members()
+            .iter()
+            .map(|state| state.clone().into_authed_msg())
+            .collect();
 
         Ok(SystemMsg::AntiEntropyUpdate {
             section_auth: sap.to_msg(),
@@ -186,11 +175,8 @@ impl Core {
         node_state: SectionAuth<NodeState>,
     ) -> Vec<Command> {
         let peer = node_state.peer().clone();
-        info!(
-            "Our section with {:?} has approved peer {}.",
-            self.network_knowledge.prefix().await,
-            peer,
-        );
+        let prefix = self.network_knowledge.prefix().await;
+        info!("Our section with {:?} has approved peer {}.", prefix, peer,);
 
         let node_msg = SystemMsg::JoinResponse(Box::new(JoinResponse::Approval {
             genesis_key: *self.network_knowledge.genesis_key(),
@@ -221,10 +207,10 @@ impl Core {
         let our_name = self.node.read().await.name();
         let nodes: Vec<_> = self
             .network_knowledge
-            .active_members()
-            .await
+            .section_members()
             .into_iter()
-            .filter(|peer| peer.name() != our_name)
+            .filter(|info| info.name() != our_name)
+            .map(|info| info.peer().clone())
             .collect();
 
         if nodes.is_empty() {
@@ -236,7 +222,7 @@ impl Core {
         let dst_section_pk = self.network_knowledge.section_key().await;
         // the previous PK which is likely what adults know
         let previous_pk = *self.section_chain().await.prev_key();
-        let node_msg = match self.generate_ae_update(previous_pk, true).await {
+        let node_msg = match self.generate_ae_update_msg(previous_pk).await {
             Ok(node_msg) => node_msg,
             Err(err) => {
                 warn!(
@@ -314,15 +300,9 @@ impl Core {
         recipients: Vec<Peer>,
         target_pk: BlsPublicKey,
     ) -> Result<Vec<Command>> {
-        let chunk_data = self.get_data_of(&prefix).await;
-        let reg_data = self.register_storage.get_data_of(prefix).await?;
+        let metadata = self.get_metadata_of(&prefix).await;
 
-        let data_update_msg = SystemMsg::NodeCmd(NodeCmd::ReceiveExistingData {
-            metadata: DataExchange {
-                chunk_data,
-                reg_data,
-            },
-        });
+        let data_update_msg = SystemMsg::NodeCmd(NodeCmd::ReceiveMetadata { metadata });
 
         match self
             .send_direct_message_to_nodes_in_section(
@@ -345,10 +325,10 @@ impl Core {
     }
 
     pub(crate) async fn send_ae_update_to_adults(&self) -> Vec<Command> {
-        let adults = self.network_knowledge.live_adults().await;
-
+        let adults = self.network_knowledge.adults().await;
         let dst_section_pk = self.network_knowledge.section_key().await;
-        let node_msg = match self.generate_ae_update(dst_section_pk, true).await {
+
+        let node_msg = match self.generate_ae_update_msg(dst_section_pk).await {
             Ok(node_msg) => node_msg,
             Err(err) => {
                 warn!(
