@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -7,16 +7,14 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    system::{KeyedSig, SectionAuth, SystemMsg},
+    system::{KeyedSig, SectionAuth, SectionPeers, SystemMsg},
     MessageId, MessageType, SrcLocation, WireMsg,
 };
 use crate::node::{
     error::{Error, Result},
     routing::{
-        api::command::Command,
-        core::Core,
-        messages::WireMsgUtils,
-        network_knowledge::{SectionAuthorityProvider, SectionPeers},
+        api::command::Command, core::Core, messages::WireMsgUtils,
+        network_knowledge::SectionAuthorityProvider,
     },
 };
 use crate::peer::Peer;
@@ -27,6 +25,7 @@ use bls::PublicKey as BlsPublicKey;
 use bytes::Bytes;
 use itertools::Itertools;
 use secured_linked_list::SecuredLinkedList;
+use std::collections::BTreeSet;
 use std::time::Duration;
 use xor_name::XorName;
 
@@ -37,9 +36,16 @@ impl Core {
         section_auth: SectionAuthorityProvider,
         section_signed: KeyedSig,
         proof_chain: SecuredLinkedList,
-        members: Option<SectionPeers>,
+        members: SectionPeers,
     ) -> Result<Vec<Command>> {
         let snapshot = self.state_snapshot().await;
+        let old_adults: BTreeSet<_> = self
+            .network_knowledge
+            .adults()
+            .await
+            .iter()
+            .map(|p| p.name())
+            .collect();
 
         let our_name = self.node.read().await.name();
         let signed_sap = SectionAuth {
@@ -52,15 +58,13 @@ impl Core {
             .update_knowledge_if_valid(
                 signed_sap.clone(),
                 &proof_chain,
-                members,
+                Some(members),
                 &our_name,
                 &self.section_keys_provider,
             )
             .await?;
 
-        let mut commands = vec![];
-
-        commands.extend(self.fire_node_event_for_any_new_adults().await?);
+        let mut commands = self.try_reorganize_data(old_adults).await?;
 
         // always run this, only changes will trigger events
         commands.extend(
@@ -347,10 +351,11 @@ impl Core {
             }
         }
 
+        let section_key = self.network_knowledge.section_key().await;
         trace!(
             "Performing AE checks, provided pk was: {:?} ours is: {:?}",
             dst_section_key,
-            self.network_knowledge.section_key().await
+            section_key
         );
 
         if dst_section_key == &self.network_knowledge.section_key().await {
