@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
 // https://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
@@ -7,7 +7,8 @@
 // specific language governing permissions and limitations relating to use of the SAFE Network
 // Software.
 
-use super::{PublicKey, RegisterAddress};
+use super::{register::User, RegisterAddress};
+
 use crate::messaging::data::Error as ErrorMessage;
 
 use std::{
@@ -15,7 +16,6 @@ use std::{
     fmt::{self, Debug, Formatter},
     result,
 };
-
 use thiserror::Error;
 
 /// A specialised `Result` type for types crate.
@@ -39,9 +39,9 @@ impl<'a, T> Debug for ErrorDebug<'a, T> {
 #[non_exhaustive]
 #[allow(clippy::large_enum_variant)]
 pub enum Error {
-    /// Access denied for supplied PublicKey
-    #[error("Access denied for PublicKey: {0}")]
-    AccessDenied(PublicKey),
+    /// Access denied for user
+    #[error("Access denied for user: {0:?}")]
+    AccessDenied(User),
     /// Serialization error
     #[error("Serialisation error: {0}")]
     Serialisation(String),
@@ -57,6 +57,9 @@ pub enum Error {
     /// Entry is too big to fit inside a register
     #[error("Entry is too big to fit inside a register: {0}, max: {1}")]
     EntryTooBig(usize, usize),
+    /// Cannot add another entry since the register entry cap has been reached.
+    #[error("Cannot add another entry since the register entry cap has been reached: {0}")]
+    TooManyEntries(usize),
     /// Supplied actions are not valid
     #[error("Some entry actions are not valid")]
     InvalidEntryActions(BTreeMap<Vec<u8>, Error>),
