@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
 // https://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
@@ -24,7 +24,8 @@ mod keys;
 mod token;
 
 pub use address::{
-    BytesAddress, ChunkAddress, DataAddress, RegisterAddress, SafeKeyAddress, Scope,
+    BytesAddress, ChunkAddress, DataAddress, RegisterAddress, ReplicatedDataAddress,
+    SafeKeyAddress, Scope,
 };
 pub use cache::Cache;
 pub use chunk::{Chunk, MAX_CHUNK_SIZE_IN_BYTES};
@@ -38,4 +39,29 @@ pub use keys::{
 };
 pub use token::Token;
 
+use crate::messaging::data::{RegisterCmd, ReplicatedRegisterLog};
+
+use serde::{Deserialize, Serialize};
 use xor_name::XorName;
+
+///
+#[allow(clippy::large_enum_variant)]
+#[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
+pub enum ReplicatedData {
+    /// A chunk of data.
+    Chunk(Chunk),
+    /// A single cmd for a register.
+    RegisterWrite(RegisterCmd),
+    /// An entire op log of a register.
+    RegisterLog(ReplicatedRegisterLog),
+}
+
+impl ReplicatedData {
+    pub(crate) fn name(&self) -> XorName {
+        match self {
+            Self::Chunk(chunk) => *chunk.name(),
+            Self::RegisterLog(log) => *log.address.name(),
+            Self::RegisterWrite(cmd) => *cmd.dst_address().name(),
+        }
+    }
+}
