@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
 // https://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
@@ -17,9 +17,10 @@ pub use policy::{
 };
 pub use reg_crdt::EntryHash;
 
-use super::{Error, PublicKey, Result};
+use super::{Error, Result};
 use crate::{types::RegisterAddress as Address, types::Scope};
 use reg_crdt::{CrdtOperation, RegisterCrdt};
+use self_encryption::MIN_ENCRYPTABLE_BYTES;
 use serde::{Deserialize, Serialize};
 use std::{
     collections::{BTreeMap, BTreeSet},
@@ -27,10 +28,8 @@ use std::{
 };
 use xor_name::XorName;
 
-use self_encryption::MIN_ENCRYPTABLE_BYTES;
-
 /// Arbitrary maximum size of a register entry.
-const MAX_REG_ENTRY_SIZE: usize = MIN_ENCRYPTABLE_BYTES;
+const MAX_REG_ENTRY_SIZE: usize = MIN_ENCRYPTABLE_BYTES / 3; // 1024 bytes
 
 /// Register mutation operation to apply to Register.
 pub type RegisterOp<T> = CrdtOperation<T>;
@@ -38,22 +37,39 @@ pub type RegisterOp<T> = CrdtOperation<T>;
 /// Object storing the Register
 #[derive(Clone, Eq, PartialEq, PartialOrd, Hash, Serialize, Deserialize, Debug)]
 pub struct Register {
-    authority: PublicKey,
+    authority: User,
     crdt: RegisterCrdt,
     policy: Policy,
+    cap: u16,
 }
 
 impl Register {
+    ///
+    pub fn new(name: XorName, tag: u64, policy: Policy, cap: u16) -> Self {
+        let address = if matches!(policy, Policy::Public(_)) {
+            Address::Public { name, tag }
+        } else {
+            Address::Private { name, tag }
+        };
+        Self {
+            authority: *policy.owner(),
+            crdt: RegisterCrdt::new(address),
+            policy,
+            cap,
+        }
+    }
+
     /// Construct a new Public Register.
     /// The 'authority' is assumed to be the PK which the messages were and will be
     /// signed with.
     /// If a policy is not provided, a default policy will be set where
     /// the 'authority' is the owner along with an empty users permissions set.
     pub fn new_public(
-        authority: PublicKey,
+        authority: User,
         name: XorName,
         tag: u64,
         policy: Option<PublicPolicy>,
+        cap: u16,
     ) -> Self {
         let policy = policy.unwrap_or(PublicPolicy {
             owner: authority,
@@ -64,6 +80,7 @@ impl Register {
             authority,
             crdt: RegisterCrdt::new(Address::Public { name, tag }),
             policy: policy.into(),
+            cap,
         }
     }
 
@@ -73,10 +90,11 @@ impl Register {
     /// If a policy is not provided, a default policy will be set where
     /// the 'authority' is the owner along with an empty users permissions set.
     pub fn new_private(
-        authority: PublicKey,
+        authority: User,
         name: XorName,
         tag: u64,
         policy: Option<PrivatePolicy>,
+        cap: u16,
     ) -> Self {
         let policy = policy.unwrap_or(PrivatePolicy {
             owner: authority,
@@ -87,9 +105,20 @@ impl Register {
             authority,
             crdt: RegisterCrdt::new(Address::Private { name, tag }),
             policy: policy.into(),
+            cap,
         }
     }
 
+    /// Return `true` if public.
+    pub fn is_public(&self) -> bool {
+        self.address().is_public()
+    }
+
+    /// Return `true` if private.
+    pub fn is_private(&self) -> bool {
+        self.address().is_private()
+    }
+
     /// Return the address.
     pub fn address(&self) -> &Address {
         self.crdt.address()
@@ -110,41 +139,54 @@ impl Register {
         self.address().tag()
     }
 
-    /// Return `true` if public.
-    pub fn is_public(&self) -> bool {
-        self.address().is_public()
+    /// Return the owner of the data.
+    pub fn owner(&self) -> User {
+        *self.policy.owner()
     }
 
-    /// Return `true` if private.
-    pub fn is_private(&self) -> bool {
-        self.address().is_private()
+    /// Return the PK which the messages are expected to be signed with by this replica.
+    pub fn replica_authority(&self) -> User {
+        self.authority
     }
 
-    /// Return the number of items held in the register, optionally
-    /// verifying read permissions if a pk is provided
-    pub fn size(&self, requester: Option<PublicKey>) -> Result<u64> {
-        self.check_permissions(Action::Read, requester)?;
+    /// Return the max number of items that can be held in the register.
+    pub fn cap(&self) -> u16 {
+        self.cap
+    }
 
-        Ok(self.crdt.size())
+    /// Return the number of items held in the register
+    pub fn size(&self) -> u64 {
+        self.crdt.size()
     }
 
     /// Return true if the register is empty.
-    pub fn is_empty(&self, requester: Option<PublicKey>) -> Result<bool> {
-        Ok(self.size(requester)? == 0)
+    pub fn is_empty(&self) -> bool {
+        self.size() == 0
     }
 
     /// Return a value corresponding to the provided 'hash', if present.
-    pub fn get(&self, hash: EntryHash, requester: Option<PublicKey>) -> Result<Option<&Entry>> {
-        self.check_permissions(Action::Read, requester)?;
-
-        Ok(self.crdt.get(hash))
+    pub fn get(&self, hash: EntryHash) -> Result<&Entry> {
+        self.crdt.get(hash).ok_or(Error::NoSuchEntry)
     }
 
     /// Read the last entry, or entries when there are branches, if the register is not empty.
-    pub fn read(&self, requester: Option<PublicKey>) -> Result<BTreeSet<(EntryHash, Entry)>> {
-        self.check_permissions(Action::Read, requester)?;
+    pub fn read(&self) -> BTreeSet<(EntryHash, Entry)> {
+        self.crdt.read()
+    }
 
-        Ok(self.crdt.read())
+    /// Return user permissions, if applicable.
+    pub fn permissions(&self, user: User) -> Result<Permissions> {
+        self.policy.permissions(user).ok_or(Error::NoSuchEntry)
+    }
+
+    /// Return the policy.
+    pub fn policy(&self) -> &Policy {
+        &self.policy
+    }
+
+    /// Increment the size cap of the register, returning the previous value.
+    pub fn increment_cap(&mut self, add: u16) {
+        self.cap += add;
     }
 
     /// Write an entry to the Register, returning the generated unsigned
@@ -155,57 +197,32 @@ impl Register {
         entry: Entry,
         children: BTreeSet<EntryHash>,
     ) -> Result<(EntryHash, RegisterOp<Entry>)> {
-        self.check_permissions(Action::Write, None)?;
-
         let size = entry.len();
         if size > MAX_REG_ENTRY_SIZE {
             return Err(Error::EntryTooBig(size, MAX_REG_ENTRY_SIZE));
         }
+        if self.crdt.size() >= self.cap() as u64 {
+            return Err(Error::TooManyEntries(self.crdt.size() as usize));
+        }
 
         self.crdt.write(entry, children, self.authority)
     }
 
     /// Apply a signed data CRDT operation.
     pub fn apply_op(&mut self, op: RegisterOp<Entry>) -> Result<()> {
-        self.check_permissions(Action::Write, Some(op.source))?;
-
         self.crdt.apply_op(op)
     }
 
-    /// Return user permissions, if applicable.
-    pub fn permissions(&self, user: User, requester: Option<PublicKey>) -> Result<Permissions> {
-        self.check_permissions(Action::Read, requester)?;
-
-        self.policy.permissions(user).ok_or(Error::NoSuchEntry)
-    }
-
-    /// Return the policy.
-    pub fn policy(&self, requester: Option<PublicKey>) -> Result<&Policy> {
-        self.check_permissions(Action::Read, requester)?;
-
-        Ok(&self.policy)
-    }
-
     /// Helper to check permissions for given `action`
     /// for the given requester's public key.
     ///
     /// Returns:
     /// `Ok(())` if the permissions are valid,
     /// `Err::AccessDenied` if the action is not allowed.
-    pub fn check_permissions(&self, action: Action, requester: Option<PublicKey>) -> Result<()> {
+    pub fn check_permissions(&self, action: Action, requester: Option<User>) -> Result<()> {
         let requester = requester.unwrap_or(self.authority);
         self.policy.is_action_allowed(requester, action)
     }
-
-    /// Return the owner of the data.
-    pub fn owner(&self) -> PublicKey {
-        *self.policy.owner()
-    }
-
-    /// Return the PK which the messages are expected to be signed with by this replica.
-    pub fn replica_authority(&self) -> PublicKey {
-        self.authority
-    }
 }
 
 #[cfg(test)]
@@ -218,7 +235,6 @@ mod tests {
         utils, Error, Keypair, Result,
     };
     use crate::{types::RegisterAddress as Address, types::Scope};
-    use eyre::eyre;
     use proptest::prelude::*;
     use rand::{rngs::OsRng, seq::SliceRandom, thread_rng};
     use std::{
@@ -229,80 +245,81 @@ mod tests {
 
     #[test]
     fn register_create_public() {
-        let register_name = XorName::random();
-        let register_tag = 43_000;
-        let (authority_keypair, register) =
-            &gen_pub_reg_replicas(None, register_name, register_tag, None, 1)[0];
+        let name = XorName::random();
+        let tag = 43_000;
+        let (authority_keypair, register) = &gen_pub_reg_replicas(None, name, tag, None, 1)[0];
 
         assert_eq!(register.scope(), Scope::Public);
-        assert_eq!(*register.name(), register_name);
-        assert_eq!(register.tag(), register_tag);
+        assert_eq!(*register.name(), name);
+        assert_eq!(register.tag(), tag);
         assert!(register.is_public());
         assert!(!register.is_private());
 
-        let authority_pk = authority_keypair.public_key();
-        assert_eq!(register.owner(), authority_pk);
-        assert_eq!(register.replica_authority(), authority_pk);
+        let authority = User::Key(authority_keypair.public_key());
+        assert_eq!(register.owner(), authority);
+        assert_eq!(register.replica_authority(), authority);
 
-        let register_address = Address::new(register_name, Scope::Public, register_tag);
-        assert_eq!(*register.address(), register_address);
+        let address = Address::new(name, Scope::Public, tag);
+        assert_eq!(*register.address(), address);
     }
 
     #[test]
     fn register_create_private() {
-        let register_name = XorName::random();
-        let register_tag = 43_000;
-        let (authority_keypair, register) =
-            &gen_priv_reg_replicas(None, register_name, register_tag, None, 1)[0];
+        let name = XorName::random();
+        let tag = 43_000;
+        let (authority_keypair, register) = &gen_priv_reg_replicas(None, name, tag, None, 1)[0];
 
         assert_eq!(register.scope(), Scope::Private);
-        assert_eq!(*register.name(), register_name);
-        assert_eq!(register.tag(), register_tag);
+        assert_eq!(*register.name(), name);
+        assert_eq!(register.tag(), tag);
         assert!(!register.is_public());
         assert!(register.is_private());
 
-        let authority_pk = authority_keypair.public_key();
-        assert_eq!(register.owner(), authority_pk);
-        assert_eq!(register.replica_authority(), authority_pk);
+        let authority = User::Key(authority_keypair.public_key());
+        assert_eq!(register.owner(), authority);
+        assert_eq!(register.replica_authority(), authority);
 
-        let register_address = Address::new(register_name, Scope::Private, register_tag);
-        assert_eq!(*register.address(), register_address);
+        let address = Address::new(name, Scope::Private, tag);
+        assert_eq!(*register.address(), address);
     }
 
     #[test]
     fn register_concurrent_write_ops() -> Result<()> {
         let authority_keypair1 = Keypair::new_ed25519(&mut OsRng);
-        let authority1 = authority_keypair1.public_key();
+        let authority1 = User::Key(authority_keypair1.public_key());
         let authority_keypair2 = Keypair::new_ed25519(&mut OsRng);
-        let authority2 = authority_keypair2.public_key();
+        let authority2 = User::Key(authority_keypair2.public_key());
 
-        let register_name: XorName = rand::random();
-        let register_tag = 43_000u64;
+        let name: XorName = rand::random();
+        let tag = 43_000u64;
+        let cap = u16::MAX;
 
         // We'll have 'authority1' as the owner in both replicas and
         // grant permissions for Write to 'authority2' in both replicas too
         let mut perms = BTreeMap::default();
         let user_perms = PublicPermissions::new(true);
-        let _prev = perms.insert(User::Key(authority2), user_perms);
+        let _prev = perms.insert(authority2, user_perms);
 
         // Instantiate the same Register on two replicas with the two diff authorities
         let mut replica1 = Register::new_public(
             authority1,
-            register_name,
-            register_tag,
+            name,
+            tag,
             Some(PublicPolicy {
                 owner: authority1,
                 permissions: perms.clone(),
             }),
+            cap,
         );
         let mut replica2 = Register::new_public(
             authority2,
-            register_name,
-            register_tag,
+            name,
+            tag,
             Some(PublicPolicy {
                 owner: authority1,
                 permissions: perms,
             }),
+            cap,
         );
 
         // And let's write an item to replica1 with autority1
@@ -311,8 +328,8 @@ mod tests {
         let signed_write_op1 = sign_register_op(op1, &authority_keypair1)?;
 
         // Let's assert current state on both replicas
-        assert_eq!(replica1.size(None)?, 1);
-        assert_eq!(replica2.size(None)?, 0);
+        assert_eq!(replica1.size(), 1);
+        assert_eq!(replica2.size(), 0);
 
         // Concurrently write another item with authority2 on replica2
         let item2 = random_register_entry();
@@ -320,7 +337,7 @@ mod tests {
         let signed_write_op2 = sign_register_op(op2, &authority_keypair2)?;
 
         // Item should be writeed on replica2
-        assert_eq!(replica2.size(None)?, 1);
+        assert_eq!(replica2.size(), 1);
 
         // Write operations are now broadcasted and applied to both replicas
         replica1.apply_op(signed_write_op2)?;
@@ -351,37 +368,37 @@ mod tests {
 
         let (entry3_hash, _) = register.write(entry3.clone(), children)?;
 
-        assert_eq!(register.size(None)?, 3);
+        assert_eq!(register.size(), 3);
 
-        let first_entry = register.get(entry1_hash, None)?;
-        assert_eq!(first_entry, Some(&entry1));
+        let first_entry = register.get(entry1_hash)?;
+        assert_eq!(first_entry, &entry1);
 
-        let second_entry = register.get(entry2_hash, None)?;
-        assert_eq!(second_entry, Some(&entry2));
+        let second_entry = register.get(entry2_hash)?;
+        assert_eq!(second_entry, &entry2);
 
-        let third_entry = register.get(entry3_hash, None)?;
-        assert_eq!(third_entry, Some(&entry3));
+        let third_entry = register.get(entry3_hash)?;
+        assert_eq!(third_entry, &entry3);
 
         let non_existing_hash = EntryHash::default();
-        let entry_not_found = register.get(non_existing_hash, None)?;
-        assert!(entry_not_found.is_none());
+        let entry_not_found = register.get(non_existing_hash);
+        assert_eq!(entry_not_found, Err(Error::NoSuchEntry));
 
         Ok(())
     }
 
     #[test]
     fn register_query_public_policy() -> eyre::Result<()> {
-        let register_name = XorName::random();
-        let register_tag = 43_666;
+        let name = XorName::random();
+        let tag = 43_666;
 
         // one replica will allow write ops to anyone
         let authority_keypair1 = Keypair::new_ed25519(&mut OsRng);
-        let owner1 = authority_keypair1.public_key();
+        let owner1 = User::Key(authority_keypair1.public_key());
         let mut perms1 = BTreeMap::default();
         let _prev = perms1.insert(User::Anyone, PublicPermissions::new(true));
         let replica1 = create_public_reg_replica_with(
-            register_name,
-            register_tag,
+            name,
+            tag,
             Some(authority_keypair1),
             Some(PublicPolicy {
                 owner: owner1,
@@ -391,12 +408,12 @@ mod tests {
 
         // the other replica will allow write ops to 'owner1' and 'authority2' only
         let authority_keypair2 = Keypair::new_ed25519(&mut OsRng);
-        let authority2 = authority_keypair2.public_key();
+        let authority2 = User::Key(authority_keypair2.public_key());
         let mut perms2 = BTreeMap::default();
-        let _prev = perms2.insert(User::Key(owner1), PublicPermissions::new(true));
+        let _prev = perms2.insert(owner1, PublicPermissions::new(true));
         let replica2 = create_public_reg_replica_with(
-            register_name,
-            register_tag,
+            name,
+            tag,
             Some(authority_keypair2),
             Some(PublicPolicy {
                 owner: authority2,
@@ -407,40 +424,44 @@ mod tests {
         assert_eq!(replica1.owner(), owner1);
         assert_eq!(replica1.replica_authority(), owner1);
         assert_eq!(
-            replica1.policy(None)?.permissions(User::Anyone),
+            replica1.policy().permissions(User::Anyone),
             Some(Permissions::Public(PublicPermissions::new(true))),
         );
         assert_eq!(
-            replica1.permissions(User::Anyone, None)?,
+            replica1.permissions(User::Anyone)?,
             Permissions::Public(PublicPermissions::new(true)),
         );
 
         assert_eq!(replica2.owner(), authority2);
         assert_eq!(replica2.replica_authority(), authority2);
         assert_eq!(
-            replica2.policy(None)?.permissions(User::Key(owner1)),
+            replica2.policy().permissions(owner1),
             Some(Permissions::Public(PublicPermissions::new(true))),
         );
         assert_eq!(
-            replica2.permissions(User::Key(owner1), None)?,
+            replica2.permissions(owner1)?,
             Permissions::Public(PublicPermissions::new(true)),
         );
 
+        let random_keypair = Keypair::new_ed25519(&mut OsRng);
+        let random_user = User::Key(random_keypair.public_key());
+        assert_eq!(replica2.permissions(random_user), Err(Error::NoSuchEntry),);
+
         Ok(())
     }
 
     #[test]
     fn register_query_private_policy() -> eyre::Result<()> {
-        let register_name = XorName::random();
-        let register_tag = 43_666;
+        let name = XorName::random();
+        let tag = 43_666;
 
         let authority_keypair1 = Keypair::new_ed25519(&mut OsRng);
-        let authority1 = authority_keypair1.public_key();
+        let authority1 = User::Key(authority_keypair1.public_key());
         let authority_keypair2 = Keypair::new_ed25519(&mut OsRng);
-        let authority2 = authority_keypair2.public_key();
+        let authority2 = User::Key(authority_keypair2.public_key());
 
         let mut perms1 = BTreeMap::default();
-        let user_perms1 = PrivatePermissions::new(/*read*/ true, /*write*/ false);
+        let user_perms1 = PrivatePermissions::new(/*read*/ true, /*write*/ false); // trying to set write perms to false for the owner (will not be reflected as long as the user is the owner, as an owner will have full authority)
         let _prev = perms1.insert(authority1, user_perms1);
 
         let mut perms2 = BTreeMap::default();
@@ -450,8 +471,8 @@ mod tests {
         let _prev = perms2.insert(authority1, user_perms2);
 
         let replica1 = create_private_reg_replica_with(
-            register_name,
-            register_tag,
+            name,
+            tag,
             Some(authority_keypair1),
             Some(PrivatePolicy {
                 owner: authority1,
@@ -460,8 +481,8 @@ mod tests {
         );
 
         let replica2 = create_private_reg_replica_with(
-            register_name,
-            register_tag,
+            name,
+            tag,
             Some(authority_keypair2),
             Some(PrivatePolicy {
                 owner: authority2,
@@ -471,171 +492,35 @@ mod tests {
 
         assert_eq!(replica1.owner(), authority1);
         assert_eq!(replica1.replica_authority(), authority1);
+        // above the owner perms were set to more restrictive than full, we test below that
+        // write&read perms for the owner will always be true, as an owner will always have full authority (even if perms were explicitly set some other way)
         assert_eq!(
-            replica1
-                .policy(Some(authority1))?
-                .permissions(User::Key(authority1)),
-            Some(Permissions::Private(PrivatePermissions::new(true, false))),
+            replica1.policy().permissions(authority1),
+            Some(Permissions::Private(PrivatePermissions::new(true, true))),
         );
         assert_eq!(
-            replica1.permissions(User::Key(authority1), Some(authority1))?,
-            Permissions::Private(PrivatePermissions::new(true, false)),
+            replica1.permissions(authority1)?,
+            Permissions::Private(PrivatePermissions::new(true, true)),
         );
 
         assert_eq!(replica2.owner(), authority2);
         assert_eq!(replica2.replica_authority(), authority2);
         assert_eq!(
-            replica2
-                .policy(Some(authority2))?
-                .permissions(User::Key(authority2)),
+            replica2.policy().permissions(authority2),
             Some(Permissions::Private(PrivatePermissions::new(true, true))),
         );
         assert_eq!(
-            replica2.permissions(User::Key(authority2), Some(authority2))?,
+            replica2.permissions(authority2)?,
             Permissions::Private(PrivatePermissions::new(true, true)),
         );
         assert_eq!(
-            replica2.permissions(User::Key(authority1), None)?,
+            replica2.permissions(authority1)?,
             Permissions::Private(PrivatePermissions::new(false, true)),
         );
 
-        Ok(())
-    }
-
-    #[test]
-    fn register_public_write_fails_when_no_perms_for_authority() -> eyre::Result<()> {
-        let register_name = XorName::random();
-        let register_tag = 43_666;
-
-        // one replica will allow write ops to anyone
-        let authority_keypair1 = Keypair::new_ed25519(&mut OsRng);
-        let owner1 = authority_keypair1.public_key();
-        let mut perms1 = BTreeMap::default();
-        let _prev = perms1.insert(User::Anyone, PublicPermissions::new(true));
-        let mut replica1 = create_public_reg_replica_with(
-            register_name,
-            register_tag,
-            Some(authority_keypair1.clone()),
-            Some(PublicPolicy {
-                owner: owner1,
-                permissions: perms1,
-            }),
-        );
-
-        // the other replica will *not* allow write ops to 'owner1'
-        let authority_keypair2 = Keypair::new_ed25519(&mut OsRng);
-        let authority2 = authority_keypair2.public_key();
-        let mut perms2 = BTreeMap::default();
-        let _prev = perms2.insert(User::Key(owner1), PublicPermissions::new(false));
-        let mut replica2 = create_public_reg_replica_with(
-            register_name,
-            register_tag,
-            Some(authority_keypair2.clone()),
-            Some(PublicPolicy {
-                owner: authority2,
-                permissions: perms2,
-            }),
-        );
-
-        // let's write to both replicas with one first item
-        let item1 = random_register_entry();
-        let item2 = random_register_entry();
-        let (_, op1) = replica1.write(item1, BTreeSet::new())?;
-        let write_op1 = sign_register_op(op1, &authority_keypair1)?;
-        check_op_not_allowed_failure(replica2.apply_op(write_op1))?;
-
-        let (_, op2) = replica2.write(item2, BTreeSet::new())?;
-        let write_op2 = sign_register_op(op2, &authority_keypair2)?;
-        replica1.apply_op(write_op2)?;
-
-        assert_eq!(replica1.size(None)?, 2);
-        assert_eq!(replica2.size(None)?, 1);
-
-        Ok(())
-    }
-
-    #[test]
-    fn register_private_write_fails_when_no_perms_for_authority() -> eyre::Result<()> {
-        let register_name = XorName::random();
-        let register_tag = 43_666;
-        let authority_keypair1 = Keypair::new_ed25519(&mut OsRng);
-        let authority1 = authority_keypair1.public_key();
-        let authority_keypair2 = Keypair::new_ed25519(&mut OsRng);
-        let authority2 = authority_keypair2.public_key();
-
-        let mut perms1 = BTreeMap::default();
-        let user_perms1 = PrivatePermissions::new(/*read*/ false, /*write*/ true);
-        let _prev = perms1.insert(authority2, user_perms1);
-
-        let mut perms2 = BTreeMap::default();
-        let user_perms2 = PrivatePermissions::new(/*read*/ true, /*write*/ false);
-        let _prev = perms2.insert(authority1, user_perms2);
-
-        let mut replica1 = create_private_reg_replica_with(
-            register_name,
-            register_tag,
-            Some(authority_keypair1.clone()),
-            Some(PrivatePolicy {
-                owner: authority1,
-                permissions: perms1,
-            }),
-        );
-
-        let mut replica2 = create_private_reg_replica_with(
-            register_name,
-            register_tag,
-            Some(authority_keypair2.clone()),
-            Some(PrivatePolicy {
-                owner: authority2,
-                permissions: perms2,
-            }),
-        );
-
-        // let's try to write to both registers
-        let item1 = random_register_entry();
-        let item2 = random_register_entry();
-
-        let (entry1_hash, op1) = replica1.write(item1.clone(), BTreeSet::new())?;
-        let write_op1 = sign_register_op(op1, &authority_keypair1)?;
-        check_op_not_allowed_failure(replica2.apply_op(write_op1))?;
-
-        let (entry2_hash, op2) = replica2.write(item2.clone(), BTreeSet::new())?;
-        let write_op2 = sign_register_op(op2, &authority_keypair2)?;
-        replica1.apply_op(write_op2)?;
-
-        assert_eq!(replica1.size(None)?, 2);
-        assert_eq!(replica2.size(None)?, 1);
-
-        // Let's do some read permissions check now...
-
-        // let's check authority1 can read from replica1 and replica2
-        let data = replica1.get(entry1_hash, Some(authority1))?;
-        let last = replica1.read(Some(authority1))?;
-        assert_eq!(data, Some(&item1));
-        assert_eq!(
-            last,
-            vec![(entry1_hash, item1), (entry2_hash, item2.clone())]
-                .into_iter()
-                .collect()
-        );
-
-        let data = replica2.get(entry2_hash, Some(authority1))?;
-        let last = replica2.read(Some(authority1))?;
-        assert_eq!(data, Some(&item2));
-        assert_eq!(
-            last,
-            vec![(entry2_hash, item2.clone())].into_iter().collect()
-        );
-
-        // authority2 cannot read from replica1
-        check_op_not_allowed_failure(replica1.get(entry1_hash, Some(authority2)))?;
-        check_op_not_allowed_failure(replica1.read(Some(authority2)))?;
-
-        // but authority2 can read from replica2
-        let data = replica2.get(entry2_hash, Some(authority2))?;
-        let last = replica2.read(Some(authority2))?;
-        assert_eq!(data, Some(&item2));
-        assert_eq!(last, vec![(entry2_hash, item2)].into_iter().collect());
+        let random_keypair = Keypair::new_ed25519(&mut OsRng);
+        let random_user = User::Key(random_keypair.public_key());
+        assert_eq!(replica2.permissions(random_user), Err(Error::NoSuchEntry),);
 
         Ok(())
     }
@@ -661,8 +546,8 @@ mod tests {
                 let authority_keypair = authority_keypair
                     .clone()
                     .unwrap_or_else(|| Keypair::new_ed25519(&mut OsRng));
-                let authority = authority_keypair.public_key();
-                let register = Register::new_public(authority, name, tag, policy.clone());
+                let authority = User::Key(authority_keypair.public_key());
+                let register = Register::new_public(authority, name, tag, policy.clone(), u16::MAX);
                 (authority_keypair, register)
             })
             .collect();
@@ -683,8 +568,9 @@ mod tests {
                 let authority_keypair = authority_keypair
                     .clone()
                     .unwrap_or_else(|| Keypair::new_ed25519(&mut OsRng));
-                let authority = authority_keypair.public_key();
-                let register = Register::new_private(authority, name, tag, policy.clone());
+                let authority = User::Key(authority_keypair.public_key());
+                let register =
+                    Register::new_private(authority, name, tag, policy.clone(), u16::MAX);
                 (authority_keypair, register)
             })
             .collect();
@@ -694,10 +580,10 @@ mod tests {
     }
 
     fn create_public_reg_replicas(count: usize) -> Vec<(Keypair, Register)> {
-        let register_name = XorName::random();
-        let register_tag = 43_000;
+        let name = XorName::random();
+        let tag = 43_000;
 
-        gen_pub_reg_replicas(None, register_name, register_tag, None, count)
+        gen_pub_reg_replicas(None, name, tag, None, count)
     }
 
     fn create_public_reg_replica_with(
@@ -720,26 +606,11 @@ mod tests {
         replicas[0].1.clone()
     }
 
-    // check it fails due to not having permissions
-    fn check_op_not_allowed_failure<T>(result: Result<T>) -> eyre::Result<()> {
-        match result {
-            Err(Error::AccessDenied(_)) => Ok(()),
-            Err(err) => Err(eyre!(
-                "Error returned was the unexpected one for a non-allowed op: {}",
-                err
-            )),
-            Ok(_) => Err(eyre!(
-                "Register operation succeded unexpectedly, an AccessDenied error was expected"
-                    .to_string(),
-            )),
-        }
-    }
-
     // verify data convergence on a set of replicas and with the expected length
     fn verify_data_convergence(replicas: Vec<Register>, expected_size: u64) -> Result<()> {
         // verify all replicas have the same and expected size
         for r in &replicas {
-            assert_eq!(r.size(None)?, expected_size);
+            assert_eq!(r.size(), expected_size);
         }
 
         // now verify that the items are the same in all replicas
@@ -759,7 +630,7 @@ mod tests {
         let tag = 45_000u64;
 
         let owner_keypair = Arc::new(Keypair::new_ed25519(&mut OsRng));
-        let owner = owner_keypair.public_key();
+        let owner = User::Key(owner_keypair.public_key());
         let policy = PublicPolicy {
             owner,
             permissions: BTreeMap::default(),
@@ -768,7 +639,8 @@ mod tests {
         (1..max_quantity + 1).prop_map(move |quantity| {
             let mut replicas = Vec::with_capacity(quantity);
             for _ in 0..quantity {
-                let replica = Register::new_public(owner, xorname, tag, Some(policy.clone()));
+                let replica =
+                    Register::new_public(owner, xorname, tag, Some(policy.clone()), u16::MAX);
 
                 replicas.push(replica);
             }
@@ -801,18 +673,18 @@ mod tests {
             _data in generate_reg_entry()
         ) {
             // Instantiate the same Register on two replicas
-            let register_name = XorName::random();
-            let register_tag = 45_000u64;
+            let name = XorName::random();
+            let tag = 45_000u64;
             let owner_keypair = Keypair::new_ed25519(&mut OsRng);
             let policy = PublicPolicy {
-                owner: owner_keypair.public_key(),
+                owner: User::Key(owner_keypair.public_key()),
                 permissions: BTreeMap::default(),
             };
 
             let mut replicas = gen_pub_reg_replicas(
                 Some(owner_keypair.clone()),
-                register_name,
-                register_tag,
+                name,
+                tag,
                 Some(policy),
                 2);
             let (_, mut replica1) = replicas.remove(0);
@@ -831,19 +703,19 @@ mod tests {
             dataset in generate_dataset(1000)
         ) {
             // Instantiate the same Register on two replicas
-            let register_name = XorName::random();
-            let register_tag = 43_001u64;
+            let name = XorName::random();
+            let tag = 43_000u64;
             let owner_keypair = Keypair::new_ed25519(&mut OsRng);
             let policy = PublicPolicy {
-                owner: owner_keypair.public_key(),
+                owner: User::Key(owner_keypair.public_key()),
                 permissions: BTreeMap::default(),
             };
 
             // Instantiate the same Register on two replicas
             let mut replicas = gen_pub_reg_replicas(
                 Some(owner_keypair.clone()),
-                register_name,
-                register_tag,
+                name,
+                tag,
                 Some(policy),
                 2);
             let (_, mut replica1) = replicas.remove(0);
@@ -870,19 +742,19 @@ mod tests {
             dataset in generate_dataset(1000)
         ) {
             // Instantiate the same Register on two replicas
-            let register_name = XorName::random();
-            let register_tag = 43_002u64;
+            let name = XorName::random();
+            let tag = 43_000u64;
             let owner_keypair = Keypair::new_ed25519(&mut OsRng);
             let policy = PublicPolicy {
-                owner: owner_keypair.public_key(),
+                owner: User::Key(owner_keypair.public_key()),
                 permissions: BTreeMap::default(),
             };
 
             // Instantiate the same Register on two replicas
             let mut replicas = gen_pub_reg_replicas(
                 Some(owner_keypair.clone()),
-                register_name,
-                register_tag,
+                name,
+                tag,
                 Some(policy),
                 2);
             let (_, mut replica1) = replicas.remove(0);
@@ -1010,19 +882,19 @@ mod tests {
             dataset in generate_dataset_and_probability(1000),
         ) {
             // Instantiate the same Register on two replicas
-            let register_name = XorName::random();
-            let register_tag = 43_001u64;
+            let name = XorName::random();
+            let tag = 43_000u64;
             let owner_keypair = Keypair::new_ed25519(&mut OsRng);
             let policy = PublicPolicy {
-                owner: owner_keypair.public_key(),
+                owner: User::Key(owner_keypair.public_key()),
                 permissions: BTreeMap::default(),
             };
 
             // Instantiate the same Register on two replicas
             let mut replicas = gen_pub_reg_replicas(
                 Some(owner_keypair.clone()),
-                register_name,
-                register_tag,
+                name,
+                tag,
                 Some(policy),
                 2);
             let (_, mut replica1) = replicas.remove(0);
@@ -1048,7 +920,7 @@ mod tests {
 
             // here we statistically should have dropped some messages
             if dataset_length > 50 {
-                assert_ne!(replica2.size(None), replica1.size(None));
+                assert_ne!(replica2.size(), replica1.size());
             }
 
             // reapply all ops
@@ -1133,8 +1005,9 @@ mod tests {
             // set up a replica that has nothing to do with the rest, random xor... different owner...
             let xorname = XorName::random();
             let tag = 45_000u64;
+            let cap = u16::MAX;
             let random_owner_keypair = Keypair::new_ed25519(&mut OsRng);
-            let mut bogus_replica = Register::new_public(random_owner_keypair.public_key(), xorname, tag, None);
+            let mut bogus_replica = Register::new_public(User::Key(random_owner_keypair.public_key()), xorname, tag, None, cap);
 
             // add bogus ops from bogus replica + bogus data
             let mut children = BTreeSet::new();
