@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under the MIT license <LICENSE-MIT
 // https://opensource.org/licenses/MIT> or the Modified BSD license <LICENSE-BSD
@@ -92,7 +92,7 @@ impl Display for Token {
     fn fmt(&self, formatter: &mut Formatter) -> fmt::Result {
         let unit = self.0 / TOKEN_TO_RAW_CONVERSION;
         let remainder = self.0 % TOKEN_TO_RAW_CONVERSION;
-        write!(formatter, "{}.{}", unit, format!("{:09}", remainder))
+        write!(formatter, "{}.{:09}", unit, remainder)
     }
 }
 
